/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * xzlarf.h
 *
 * Code generation for function 'xzlarf'
 *
 */

#ifndef XZLARF_H
#define XZLARF_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern void xzlarf(int m, int n, int iv0, double tau, emxArray_real_T *C, int
                   ic0, int ldc, emxArray_real_T *work);

#endif

/* End of code generation (xzlarf.h) */
